summaryrefslogtreecommitdiff
path: root/src/libtnccs/plugins/tnc_tnccs/tnc_tnccs_manager.c
diff options
context:
space:
mode:
authorYves-Alexis Perez <corsac@debian.org>2016-07-16 15:19:53 +0200
committerYves-Alexis Perez <corsac@debian.org>2016-07-16 15:19:53 +0200
commitbf372706c469764d59e9f29c39e3ecbebd72b8d2 (patch)
tree0f0e296e2d50e4a7faf99ae6fa428d2681e81ea1 /src/libtnccs/plugins/tnc_tnccs/tnc_tnccs_manager.c
parent518dd33c94e041db0444c7d1f33da363bb8e3faf (diff)
downloadvyos-strongswan-bf372706c469764d59e9f29c39e3ecbebd72b8d2.tar.gz
vyos-strongswan-bf372706c469764d59e9f29c39e3ecbebd72b8d2.zip
Imported Upstream version 5.5.0
Diffstat (limited to 'src/libtnccs/plugins/tnc_tnccs/tnc_tnccs_manager.c')
-rw-r--r--src/libtnccs/plugins/tnc_tnccs/tnc_tnccs_manager.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/libtnccs/plugins/tnc_tnccs/tnc_tnccs_manager.c b/src/libtnccs/plugins/tnc_tnccs/tnc_tnccs_manager.c
index 67c33ee63..5ac2c85a5 100644
--- a/src/libtnccs/plugins/tnc_tnccs/tnc_tnccs_manager.c
+++ b/src/libtnccs/plugins/tnc_tnccs/tnc_tnccs_manager.c
@@ -87,7 +87,7 @@ struct tnccs_connection_entry_t {
/**
* Maximum size of a PA-TNC message
*/
- u_int32_t max_msg_len;
+ uint32_t max_msg_len;
/**
* collection of IMV recommendations
@@ -199,7 +199,7 @@ METHOD(tnccs_manager_t, create_instance, tnccs_t*,
METHOD(tnccs_manager_t, create_connection, TNC_ConnectionID,
private_tnc_tnccs_manager_t *this, tnccs_type_t type, tnccs_t *tnccs,
tnccs_send_message_t send_message, bool* request_handshake_retry,
- u_int32_t max_msg_len, recommendations_t **recs)
+ uint32_t max_msg_len, recommendations_t **recs)
{
tnccs_connection_entry_t *entry;
@@ -414,14 +414,14 @@ static TNC_Result bool_attribute(TNC_UInt32 buffer_len,
}
/**
* Write the value of an u_int32_t attribute into the buffer
*/
static TNC_Result uint_attribute(TNC_UInt32 buffer_len,
TNC_BufferReference buffer,
TNC_UInt32 *value_len,
- u_int32_t value)
+ uint32_t value)
{
- *value_len = sizeof(u_int32_t);
+ *value_len = sizeof(uint32_t);
if (buffer && buffer_len >= *value_len)
{
@@ -465,7 +465,7 @@ static TNC_Result identity_attribute(TNC_UInt32 buffer_len,
{
bio_writer_t *writer;
enumerator_t *enumerator;
- u_int32_t count;
+ uint32_t count;
chunk_t value;
tncif_identity_t *tnc_id;
TNC_Result result = TNC_RESULT_INVALID_PARAMETER;
@@ -721,7 +721,7 @@ METHOD(tnccs_manager_t, get_attribute, TNC_Result,
host_t *peer_ip;
tnccs_t *tnccs;
tncif_identity_t *tnc_id;
- u_int32_t id_type, subject_type;
+ uint32_t id_type, subject_type;
chunk_t id_value;
char *id_str;
TNC_Result result;
@@ -414,14 +414,14 @@ static TNC_Result bool_attribute(TNC_UInt32 buffer_len,
}
/**
- * Write the value of an u_int32_t attribute into the buffer
+ * Write the value of an uint32_t attribute into the buffer
*/
static TNC_Result uint_attribute(TNC_UInt32 buffer_len,